@@ -156,7 +156,9 @@ class RemoteConnection(object):
 
         self._url = remote_server_addr
         self._commands = {
+            Command.STATUS: ('GET', '/status'),
             Command.NEW_SESSION: ('POST', '/session'),
+            Command.GET_ALL_SESSIONS: ('GET', '/sessions'),
             Command.QUIT: ('DELETE', '/session/$sessionId'),
             Command.GET_CURRENT_WINDOW_HANDLE:
                 ('GET', '/session/$sessionId/window_handle'),
